import java.util.*;

/**
 * Clase Wall(muralla) hereda de PhysicsElement.
 */
public class Wall extends PhysicsElement  {
   private static float mass=Float.MAX_VALUE/1000.0f;
   private Vector2D pos;   
   private char axis;

   /**
    * Constructor Wall
    */
   public Wall(char axis, Vector2D pos, MyWorld world){
      super();
      this.axis = axis;
      this.pos = pos;
      world.addElement(this);
   }

   /**
    * Metodo getMass retorna el eje.
    */
   public char getAxis(){
      return this.axis;
   }

   /**
    * Metodo getMass retorna la masa.
    */
   public float getMass(){
      return mass;
   }

   /**
    * Metodo getRadius retorna radio, para las murallas es cero.
    */
   public float getRadius(){
      return 0.0f;
   }

   /**
    * Metodo getPosition retorna vector posición de la muralla.
    */
   public Vector2D getPosition() {
      return pos;
   }

   /**
    * Metodo getSpeed retorna vector velocida, para el caso de
    * la murallas siempre es cero.
    */
   public Vector2D getSpeed() {
      return new Vector2D(0,0);
   }

   /**
    * Metodo collide detecta el choque de esta muralla con alguna bola.
    */
   public boolean collide(PhysicsElement pe) {
       
           pe = (Ball)pe;
           float distance_X, distance_Y;

           /*
            * Calcula distancia entre la bola y cada eje de la muralla.
            */
            distance_X = Math.abs(getPosition().getX() - pe.getPosition().getX());
            distance_Y = Math.abs(getPosition().getY() - pe.getPosition().getY());

            /*
             * Comprueba choque entre la muralla y la bola dependiendo en que eje
             * se encuentre la muralla.
             */
            if(axis =='x')
                return distance_X < pe.getRadius();
            else
                return distance_Y < pe.getRadius();

   }
   
   public void computeNextState(double delta_t, MyWorld w){
   }
   
   public void updateState(){
   }

   /**
    * Retorna nombre, eje e ID de la muralla.
    */
   public String getDescription() {
      return "Wall_"+axis+"_"+ getId()+": ";
   }

   /**
    * Retorna posición en la que se encuentra la muralla.
    */
   public String getState() {
      return "("+getPosition().getX()+","+getPosition().getY()+")  ";
   }
}
